| Title: | Proximal Weighting Estimation for Dependent Left Truncation |
|---|---|
| Description: | Implements proximal weighting estimators for the expectation of an arbitrarily transformed event time under dependent left truncation, with optional inverse probability of censoring weighting to handle right censoring. The methods leverage proxy variables to handle dependent left truncation in settings where dependence-inducing factors are not fully observed. |
| Authors: | Yuyao Wang [aut, cre], Andrew Ying [aut], Ronghui Xu [aut] |
| Maintainer: | Yuyao Wang <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-22 08:26:43 UTC |
| Source: | https://github.com/wangyuyao98/truncproxy_weighting |
Computes the proximal weighting estimator for the expectation of an arbitrarily transformed event time under dependent left truncation.
PQB_estimator( nu, dat, time.name, Q.name, W1.name, W2.name, Z.name, weights = rep(1, nrow(dat)), trim.min = 1e-07, trim.max = 1e+07 )PQB_estimator( nu, dat, time.name, Q.name, W1.name, W2.name, Z.name, weights = rep(1, nrow(dat)), trim.min = 1e-07, trim.max = 1e+07 )
nu |
A user-supplied transformation of the event time. For example,
|
dat |
A data frame containing the observed data. |
time.name |
Name of the event time variable. |
Q.name |
Name of the left truncation time variable. |
W1.name |
Name of the truncation proxies. |
W2.name |
Name of the event time proxies. |
Z.name |
Name of the measured covariates that are directly associated with both the event time and the truncation time. |
weights |
Optional nonnegative case weights. Defaults to equal weights. |
trim.min |
Lower bound used to stabilize the estimated bridge weights. |
trim.max |
Upper bound used to stabilize the estimated bridge weights. |
A numeric scalar containing the proximal weighting estimator.
Computes the IPCW-adjusted proximal weighting estimator for the expectation of an arbitrarily transformed event time under dependent left truncation and random right censoring.
PQB_IPCW_estimator( nu, t0, dat, time.name, Q.name, event.name = NULL, W1.name, W2.name, Z.name, weights = rep(1, nrow(dat)), trim.min = 1e-07, trim.max = 1e+07, IPCW_time_varying = FALSE, trim.IPCW = 1e-07 )PQB_IPCW_estimator( nu, t0, dat, time.name, Q.name, event.name = NULL, W1.name, W2.name, Z.name, weights = rep(1, nrow(dat)), trim.min = 1e-07, trim.max = 1e+07, IPCW_time_varying = FALSE, trim.IPCW = 1e-07 )
nu |
A user-supplied transformation of the event time. For example,
|
t0 |
A cutoff such that |
dat |
A data frame containing the observed data. |
time.name |
Name of the observed event or censoring time variable. |
Q.name |
Name of the left truncation time variable. |
event.name |
Name of the event indicator variable. Set to |
W1.name |
Name of the truncation proxies. |
W2.name |
Name of the event time proxies. |
Z.name |
Name of the measured covariates that are directly associated with both the event time and the truncation time. |
weights |
Optional nonnegative case weights. Defaults to equal weights. |
trim.min |
Lower bound used to stabilize the estimated bridge weights. |
trim.max |
Upper bound used to stabilize the estimated bridge weights. |
IPCW_time_varying |
Logical; if |
trim.IPCW |
Lower bound used to stabilize the denominators of IPCW weights. |
A numeric scalar containing the IPCW-adjusted proximal weighting estimator.